==> segatex-7.880.tar.gz: segatex-7.880/src/semanage_core_permissive_process.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2009 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <qlayout.h>
#include <qpushbutton.h>
#include <q3process.h>
#include <qradiobutton.h>
#include <q3buttongroup.h>
#include <qlineedit.h>
#include <q3textedit.h>
//Added by qt3to4:
#include <Q3TextStream>
#include <Q3HBoxLayout>
#include <QLabel>
#include <Q3VBoxLayout>

#include <unistd.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <fstream>

#include "semanage_core_permissive_process.h"

#include <iostream>
using namespace std;

//default constructor
SemanageCorePermissiveProcess::SemanageCorePermissiveProcess(QWidget *parent, const char *name): QDialog(parent, name)
{
	setCaption(tr("Semanage Permissive Process"));
	textEdit1 = new Q3TextEdit(this);
	textEdit1->setPaletteBackgroundColor(QColor(250,180,200));

	semanageEditLabel = new QLabel(tr("Add this module permissive:"), this );
	semanageEditLineEdit = new QLineEdit( this );
	semanageEditLineEdit->setText("");
	semanageEditLineEdit->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel4 = new QLabel(tr("_t"), this );
	addButton = new QPushButton(tr("Add permissive"), this);
	addButton->setPaletteBackgroundColor(QColor(200,157,100));
	connect(addButton, SIGNAL(clicked()), this, SLOT(add_button_clicked()));

	semanageEditLabel3 = new QLabel(tr("Delete this module permissive:"), this );
	semanageEditLineEdit3 = new QLineEdit( this );
	semanageEditLineEdit3->setText("");
	semanageEditLineEdit3->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel5 = new QLabel(tr("_t"), this );
	deleteButton = new QPushButton(tr("Delete permissive"), this);
	deleteButton->setPaletteBackgroundColor(QColor(200,157,100));
	connect(deleteButton, SIGNAL(clicked()), this, SLOT(delete_button_clicked()));

	closeButton = new QPushButton(tr("close"), this);
	//closing process button
	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
	closeButton->setDefault(true);

	//set textEdit smanage such and such -l
	semanage_core_base_permissive_process();

	mainLayout = new Q3VBoxLayout(this);
	mainLayout->setMargin(11);

	upperLayout = new Q3VBoxLayout;
	upperLayout->addWidget(textEdit1);

	middleLayout = new Q3VBoxLayout;
	leftLayout = new Q3HBoxLayout;
	rightLayout = new Q3HBoxLayout;
	thirdLayout = new Q3HBoxLayout;
	
	leftLayout->addWidget(semanageEditLabel);
	leftLayout->addWidget(semanageEditLineEdit);
	leftLayout->addWidget(semanageEditLabel4);
	leftLayout->addStretch(1);
	leftLayout->addWidget(addButton);
	leftLayout->addStretch(1);
	rightLayout->addWidget(semanageEditLabel3);
	rightLayout->addWidget(semanageEditLineEdit3);
	rightLayout->addWidget(semanageEditLabel5);
	rightLayout->addStretch(1);
	rightLayout->addWidget(deleteButton);
	rightLayout->addStretch(1);

	middleLayout->addLayout(leftLayout);
	middleLayout->addLayout(rightLayout);
	middleLayout->addLayout(thirdLayout);

	footLayout = new Q3HBoxLayout;
	footLayout->addStretch();
	footLayout->addWidget(closeButton);

	mainLayout->addLayout(upperLayout);
	mainLayout->addLayout(middleLayout);
	mainLayout->addLayout(footLayout);
	resize(900,600);
}

/*signal and slot should have same argument pattern so I had to pass to another slot*/
void SemanageCorePermissiveProcess::add_button_clicked()
{
	semanageEditLineEdit_str = semanageEditLineEdit->text();
	//semanageEditLineEdit2_str = semanageEditLineEdit2->text();
	//semanageEditLineEdit6_str = semanageEditLineEdit6->text();
	//add_button_clicked_process(semanageEditLineEdit_str,semanageEditLineEdit2_str,semanageEditLineEdit6_str);
	add_button_clicked_process(semanageEditLineEdit_str);
}
/*signal and slot should have same argument pattern so I had to pass to another slot*/
void SemanageCorePermissiveProcess::delete_button_clicked()
{
	semanageEditLineEdit3_str = semanageEditLineEdit3->text();
	delete_button_clicked_process(semanageEditLineEdit3_str);
}
void SemanageCorePermissiveProcess::add_button_clicked_process(QString semanageEditLineEdit_str)
{
	semanageEditLineEdit_str_pp = "semanage permissive -a " + semanageEditLineEdit_str + "_t";
        #define PWD_BUF 8600
        const char* make_module_file="/usr/share/segatex/semanage/add_permissived";
        ofstream os_add;
        os_add.open(make_module_file);
        if(os_add){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));
                read_fp = popen(semanageEditLineEdit_str_pp, "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os_add << buffer << endl;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        }
                        pclose(read_fp);
                }
        }
	os_add.close();
	//set textEdit semanage -l
	semanage_core_base_permissive_process();
	//outputfile_str_common2 = make_module_file;
}

void SemanageCorePermissiveProcess::delete_button_clicked_process(QString semanageEditLineEdit3_str)
{
	semanageEditLineEdit_str_pp = "semanage permissive -d " + semanageEditLineEdit3_str + "_t";
        #define PWD_BUF 8600
        const char* make_module_file="/usr/share/segatex/semanage/delete_permissived";
        ofstream os_delete;
        os_delete.open(make_module_file);
        if(os_delete){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));
                read_fp = popen(semanageEditLineEdit_str_pp, "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os_delete << buffer << endl;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        }
                        pclose(read_fp);
                }
        }
	os_delete.close();
	//set textEdit semanage -l
	semanage_core_base_permissive_process();
}

void SemanageCorePermissiveProcess::semanage_core_base_permissive_process()
{
        #define PWD_BUF 8600
        const char* semanage_login_list_file="/usr/share/segatex/semanage/1_permissive";
        ofstream os;
        os.open(semanage_login_list_file);
        if(os){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));

                read_fp = popen("/usr/sbin/semodule -l|grep permissive", "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os << buffer;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
			}
			pclose(read_fp);
                }
        }
	os.close();
	//outputfile_str_common = "login_list";

        const char* semanage_user_list_file="/usr/share/segatex/semanage/2_permissive";
        ofstream os2;
        os2.open(semanage_user_list_file);
        if(os2){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));
                read_fp = popen("export LANG=C;/usr/sbin/semodule -l", "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os2 << buffer;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        }
                        pclose(read_fp);
                }
        }
	os2.close();

	readFromOutputFile();

}

//this slot should be called from above slot
void SemanageCorePermissiveProcess::readFromOutputFile()
{
	/////////////////////////////////////////////////////////////
	//path = "./";
	path = "/usr/share/segatex/semanage";
	/////////////////////////////////////////////////////////////
	forward_slash = "/";
	dir.setPath(path);
	dir_name = dir.absPath();
	/////////////////////////////////////////////////////////////
	dir.setFilter( QDir::Files );
        dir.setSorting( QDir::Name );
	//files = dir.entryList(outputfile_str_common);
	files = dir.entryList("*permissive");
	/////////////////////////////////////////////////////////////
	it_d = files.begin();
	int order_x;
	order_x = 1;
	//first clear it all, unless double the file.
	textEdit1->clear();
	while(it_d != files.end()){
		name = *it_d;
		file_interface_name = dir_name + forward_slash + name;
		QFile file( file_interface_name );
	/*
		QRegExp rx_nologin("nologin");
		QRegExp rx_shutdown("shutdown");
		QRegExp rx_halt("halt");
		QRegExp rx_news("news");
		QRegExp rx_false("false");
		QRegExp rx_sync("sync");
	*/
		if ( file.open( QIODevice::ReadOnly ) ) {
			Q3TextStream stream( &file );
			////////////////////////////////////////////
			//int i,j,k,l,m,n;	
			if(order_x == 1)
				textEdit1->append("#########permissive domain list#########");
				textEdit1->append("");
			if(order_x == 2)
				textEdit1->append("#########semodule list#########");
				textEdit1->append("");
		/*
			if(order_x == 3)
				textEdit1->append("#########etc passwd list#########");
				textEdit1->append("");
		*/
			while ( !stream.atEnd() ) {
				line_analized = stream.readLine(); // line of text excluding '\n'
				//buttons.push_back(line_analized);
				/*
				i = line_analized.find( rx_nologin, 0);
				j = line_analized.find( rx_shutdown, 0);
				k = line_analized.find( rx_halt, 0);
				l = line_analized.find( rx_news, 0);
				m = line_analized.find( rx_false, 0);
				n = line_analized.find( rx_sync, 0);
				*/
				/*
				if((i != -1)||(j != -1)||(k != -1)||(l != -1)||(m != -1)||(n != -1)){
					//do nothing
				}else{
				*/
					textEdit1->append(line_analized);
				//}
			}
			textEdit1->setCursorPosition(0,0);
			file.close();
			order_x++;
			++it_d;
		}else{
			//do nothing
		}
	}
}

==> segatex-7.900.tar.gz: segatex-7.900/src/semanage_core_permissive_process.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2013 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <qlayout.h>
#include <qpushbutton.h>
#include <q3process.h>
#include <qradiobutton.h>
#include <q3buttongroup.h>
#include <qlineedit.h>
#include <q3textedit.h>
//Added by qt3to4:
#include <Q3TextStream>
#include <Q3HBoxLayout>
#include <QLabel>
#include <Q3VBoxLayout>

#include <unistd.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <fstream>

#include "semanage_core_permissive_process.h"

#include <iostream>
using namespace std;

//default constructor
SemanageCorePermissiveProcess::SemanageCorePermissiveProcess(QWidget *parent, const char *name): QDialog(parent, name)
{
	setCaption(tr("Semanage Permissive Process"));
	textEdit1 = new Q3TextEdit(this);
	textEdit1->setPaletteBackgroundColor(QColor(250,180,200));

	semanageEditLabel = new QLabel(tr("Add this module permissive:"), this );
	semanageEditLineEdit = new QLineEdit( this );
	semanageEditLineEdit->setText("");
	semanageEditLineEdit->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel4 = new QLabel(tr("_t"), this );
	addButton = new QPushButton(tr("Add permissive"), this);
	addButton->setPaletteBackgroundColor(QColor(200,157,100));
	connect(addButton, SIGNAL(clicked()), this, SLOT(add_button_clicked()));

	semanageEditLabel3 = new QLabel(tr("Delete this module permissive:"), this );
	semanageEditLineEdit3 = new QLineEdit( this );
	semanageEditLineEdit3->setText("");
	semanageEditLineEdit3->setPaletteBackgroundColor(QColor(255,100,200));
	semanageEditLabel5 = new QLabel(tr("_t"), this );
	deleteButton = new QPushButton(tr("Delete permissive"), this);
	deleteButton->setPaletteBackgroundColor(QColor(200,157,100));
	connect(deleteButton, SIGNAL(clicked()), this, SLOT(delete_button_clicked()));

	closeButton = new QPushButton(tr("close"), this);
	//closing process button
	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
	closeButton->setDefault(true);

	//set textEdit smanage such and such -l
	semanage_core_base_permissive_process();

	mainLayout = new Q3VBoxLayout(this);
	mainLayout->setMargin(11);

	upperLayout = new Q3VBoxLayout;
	upperLayout->addWidget(textEdit1);

	middleLayout = new Q3VBoxLayout;
	leftLayout = new Q3HBoxLayout;
	rightLayout = new Q3HBoxLayout;
	thirdLayout = new Q3HBoxLayout;
	
	leftLayout->addWidget(semanageEditLabel);
	leftLayout->addWidget(semanageEditLineEdit);
	leftLayout->addWidget(semanageEditLabel4);
	leftLayout->addStretch(1);
	leftLayout->addWidget(addButton);
	leftLayout->addStretch(1);
	rightLayout->addWidget(semanageEditLabel3);
	rightLayout->addWidget(semanageEditLineEdit3);
	rightLayout->addWidget(semanageEditLabel5);
	rightLayout->addStretch(1);
	rightLayout->addWidget(deleteButton);
	rightLayout->addStretch(1);

	middleLayout->addLayout(leftLayout);
	middleLayout->addLayout(rightLayout);
	middleLayout->addLayout(thirdLayout);

	footLayout = new Q3HBoxLayout;
	footLayout->addStretch();
	footLayout->addWidget(closeButton);

	mainLayout->addLayout(upperLayout);
	mainLayout->addLayout(middleLayout);
	mainLayout->addLayout(footLayout);
	resize(900,600);
}

/*signal and slot should have same argument pattern so I had to pass to another slot*/
void SemanageCorePermissiveProcess::add_button_clicked()
{
	semanageEditLineEdit_str = semanageEditLineEdit->text();
	//semanageEditLineEdit2_str = semanageEditLineEdit2->text();
	//semanageEditLineEdit6_str = semanageEditLineEdit6->text();
	//add_button_clicked_process(semanageEditLineEdit_str,semanageEditLineEdit2_str,semanageEditLineEdit6_str);
	add_button_clicked_process(semanageEditLineEdit_str);
}
/*signal and slot should have same argument pattern so I had to pass to another slot*/
void SemanageCorePermissiveProcess::delete_button_clicked()
{
	semanageEditLineEdit3_str = semanageEditLineEdit3->text();
	delete_button_clicked_process(semanageEditLineEdit3_str);
}
void SemanageCorePermissiveProcess::add_button_clicked_process(QString semanageEditLineEdit_str)
{
	semanageEditLineEdit_str_pp = "semanage permissive -a " + semanageEditLineEdit_str + "_t";
        #define PWD_BUF 8600
        const char* make_module_file="/usr/share/segatex/semanage/add_permissived";
        ofstream os_add;
        os_add.open(make_module_file);
        if(os_add){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));
                read_fp = popen(semanageEditLineEdit_str_pp, "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os_add << buffer << endl;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        }
                        pclose(read_fp);
                }
        }
	os_add.close();
	//set textEdit semanage -l
	semanage_core_base_permissive_process();
	//outputfile_str_common2 = make_module_file;
}

void SemanageCorePermissiveProcess::delete_button_clicked_process(QString semanageEditLineEdit3_str)
{
	semanageEditLineEdit_str_pp = "semanage permissive -d " + semanageEditLineEdit3_str + "_t";
        #define PWD_BUF 8600
        const char* make_module_file="/usr/share/segatex/semanage/delete_permissived";
        ofstream os_delete;
        os_delete.open(make_module_file);
        if(os_delete){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));
                read_fp = popen(semanageEditLineEdit_str_pp, "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os_delete << buffer << endl;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        }
                        pclose(read_fp);
                }
        }
	os_delete.close();
	//set textEdit semanage -l
	semanage_core_base_permissive_process();
}

void SemanageCorePermissiveProcess::semanage_core_base_permissive_process()
{
        #define PWD_BUF 8600
        const char* semanage_login_list_file="/usr/share/segatex/semanage/1_permissive";
        ofstream os;
        os.open(semanage_login_list_file);
        if(os){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));

                //read_fp = popen("/usr/sbin/semodule -l|grep permissive", "r");
                read_fp = popen("/usr/sbin/semanage permissive -l", "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os << buffer;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
			}
			pclose(read_fp);
                }
        }
	os.close();
	//outputfile_str_common = "login_list";

        const char* semanage_user_list_file="/usr/share/segatex/semanage/2_permissive";
        ofstream os2;
        os2.open(semanage_user_list_file);
        if(os2){
                FILE *read_fp;
                #define SIZE_TMP 8600
                char buffer[SIZE_TMP];
                int chars_read;
                memset(buffer, '\0', sizeof(buffer));
                read_fp = popen("export LANG=C;/usr/sbin/semodule -l", "r");
                if(read_fp != NULL){
                        chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        while(chars_read>0){
                                buffer[chars_read -1] = '\0';
                                //os << "Reading:-" << endl;
                                os2 << buffer;
                                chars_read= fread(buffer, sizeof(char), SIZE_TMP, read_fp);
                        }
                        pclose(read_fp);
                }
        }
	os2.close();

	readFromOutputFile();

}

//this slot should be called from above slot
void SemanageCorePermissiveProcess::readFromOutputFile()
{
	/////////////////////////////////////////////////////////////
	//path = "./";
	path = "/usr/share/segatex/semanage";
	/////////////////////////////////////////////////////////////
	forward_slash = "/";
	dir.setPath(path);
	dir_name = dir.absPath();
	/////////////////////////////////////////////////////////////
	dir.setFilter( QDir::Files );
        dir.setSorting( QDir::Name );
	//files = dir.entryList(outputfile_str_common);
	files = dir.entryList("*permissive");
	/////////////////////////////////////////////////////////////
	it_d = files.begin();
	int order_x;
	order_x = 1;
	//first clear it all, unless double the file.
	textEdit1->clear();
	while(it_d != files.end()){
		name = *it_d;
		file_interface_name = dir_name + forward_slash + name;
		QFile file( file_interface_name );
	/*
		QRegExp rx_nologin("nologin");
		QRegExp rx_shutdown("shutdown");
		QRegExp rx_halt("halt");
		QRegExp rx_news("news");
		QRegExp rx_false("false");
		QRegExp rx_sync("sync");
	*/
		if ( file.open( QIODevice::ReadOnly ) ) {
			Q3TextStream stream( &file );
			////////////////////////////////////////////
			//int i,j,k,l,m,n;	
			if(order_x == 1)
				textEdit1->append("#########permissive domain list#########");
				textEdit1->append("");
			if(order_x == 2)
				textEdit1->append("#########semodule list#########");
				textEdit1->append("");
		/*
			if(order_x == 3)
				textEdit1->append("#########etc passwd list#########");
				textEdit1->append("");
		*/
			while ( !stream.atEnd() ) {
				line_analized = stream.readLine(); // line of text excluding '\n'
				//buttons.push_back(line_analized);
				/*
				i = line_analized.find( rx_nologin, 0);
				j = line_analized.find( rx_shutdown, 0);
				k = line_analized.find( rx_halt, 0);
				l = line_analized.find( rx_news, 0);
				m = line_analized.find( rx_false, 0);
				n = line_analized.find( rx_sync, 0);
				*/
				/*
				if((i != -1)||(j != -1)||(k != -1)||(l != -1)||(m != -1)||(n != -1)){
					//do nothing
				}else{
				*/
					textEdit1->append(line_analized);
				//}
			}
			textEdit1->setCursorPosition(0,0);
			file.close();
			order_x++;
			++it_d;
		}else{
			//do nothing
		}
	}
}
